==> jc-1.4.0.tar.gz: java/beans/MethodDescriptor.h <==
// public class java.beans.MethodDescriptor

// class file dependencies
// @dep_class 171fda3bb37b43ab java_beans_FeatureDescriptor
// @dep_class d4136fbffa5ebe7a java_beans_MethodDescriptor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_MethodDescriptor_H_
#define _JC_java_beans_MethodDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_beans_MethodDescriptor$sub_refs	_jc_java_beans_MethodDescriptor$sub_refs;
typedef struct _jc_java_beans_MethodDescriptor$sub_nonrefs	_jc_java_beans_MethodDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_MethodDescriptor$refs	_jc_java_beans_MethodDescriptor$refs;
typedef struct _jc_java_beans_MethodDescriptor$nonrefs	_jc_java_beans_MethodDescriptor$nonrefs;
typedef struct _jc_java_beans_MethodDescriptor$object	_jc_java_beans_MethodDescriptor$object;

typedef const struct _jc_java_beans_MethodDescriptor$vmethods	_jc_java_beans_MethodDescriptor$vmethods;
typedef const struct _jc_java_beans_MethodDescriptor$vtable	_jc_java_beans_MethodDescriptor$vtable;
typedef const struct _jc_java_beans_MethodDescriptor$vtype	_jc_java_beans_MethodDescriptor$vtype;

// Constructors
extern void _jc_java_beans_MethodDescriptor$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *, struct _jc_java_lang_reflect_Method$object *);
extern void _jc_java_beans_MethodDescriptor$method$_init$4ce67c1cbd80ba4f(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *, struct _jc_java_lang_reflect_Method$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_reflect_Method$object *_jc_java_beans_MethodDescriptor$method$getMethod$d3eefe46ed92bf50(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *);
extern _jc_object_array *_jc_java_beans_MethodDescriptor$method$getParameterDescriptors$84f840efb6d79e7e(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_MethodDescriptor$method_info$getMethod$d3eefe46ed92bf50;
extern _jc_method _jc_java_beans_MethodDescriptor$method_info$getParameterDescriptors$84f840efb6d79e7e;

// Virtual methods structure
struct _jc_java_beans_MethodDescriptor$vmethods {
	struct _jc_java_lang_reflect_Method$object	*(*getMethod$d3eefe46ed92bf50)(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *);
	_jc_object_array	*(*getParameterDescriptors$84f840efb6d79e7e)(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *);
};

// Vtable
struct _jc_java_beans_MethodDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_MethodDescriptor$vmethods	java_beans_MethodDescriptor;
};

// Vtype
struct _jc_java_beans_MethodDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_MethodDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_MethodDescriptor$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*m;
	_jc_object_array	*parameterDescriptors;
};

// Reference instance fields (object)
struct _jc_java_beans_MethodDescriptor$refs {
    _jc_java_beans_MethodDescriptor$sub_refs	java_beans_MethodDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_MethodDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_MethodDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_MethodDescriptor$sub_nonrefs	java_beans_MethodDescriptor;
};

// Object instance structure
struct _jc_java_beans_MethodDescriptor$object {
	_jc_java_beans_MethodDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_MethodDescriptor$vtype	*vtype;
	_jc_java_beans_MethodDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_MethodDescriptor$vtype _jc_java_beans_MethodDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_MethodDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_MethodDescriptor$class_object;

#endif	/* _JC_java_beans_MethodDescriptor_H_ */

==> jc-1.4.6.tar.gz: java/beans/MethodDescriptor.h <==
// public class java.beans.MethodDescriptor

// class file dependencies
// @dep_class 8327659df0b02789 java_beans_FeatureDescriptor
// @dep_class d4136fbffa5ebe7a java_beans_MethodDescriptor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_MethodDescriptor_H_
#define _JC_java_beans_MethodDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_reflect_Method$object;

// Typedefs
typedef struct _jc_java_beans_MethodDescriptor$sub_refs	_jc_java_beans_MethodDescriptor$sub_refs;
typedef struct _jc_java_beans_MethodDescriptor$sub_nonrefs	_jc_java_beans_MethodDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_MethodDescriptor$refs	_jc_java_beans_MethodDescriptor$refs;
typedef struct _jc_java_beans_MethodDescriptor$nonrefs	_jc_java_beans_MethodDescriptor$nonrefs;
typedef struct _jc_java_beans_MethodDescriptor$object	_jc_java_beans_MethodDescriptor$object;

typedef const struct _jc_java_beans_MethodDescriptor$vmethods	_jc_java_beans_MethodDescriptor$vmethods;
typedef const struct _jc_java_beans_MethodDescriptor$vtable	_jc_java_beans_MethodDescriptor$vtable;
typedef const struct _jc_java_beans_MethodDescriptor$vtype	_jc_java_beans_MethodDescriptor$vtype;

// Constructors
extern void _jc_java_beans_MethodDescriptor$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *, struct _jc_java_lang_reflect_Method$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_MethodDescriptor$method$_init$4ce67c1cbd80ba4f(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *, struct _jc_java_lang_reflect_Method$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_reflect_Method$object *_jc_java_beans_MethodDescriptor$method$getMethod$d3eefe46ed92bf50(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_beans_MethodDescriptor$method$getParameterDescriptors$84f840efb6d79e7e(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_MethodDescriptor$method_info$getMethod$d3eefe46ed92bf50;
extern _jc_method _jc_java_beans_MethodDescriptor$method_info$getParameterDescriptors$84f840efb6d79e7e;

// Virtual methods structure
struct _jc_java_beans_MethodDescriptor$vmethods {
	struct _jc_java_lang_reflect_Method$object	*(*getMethod$d3eefe46ed92bf50)(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getParameterDescriptors$84f840efb6d79e7e)(_jc_env *, struct _jc_java_beans_MethodDescriptor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_MethodDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_MethodDescriptor$vmethods	java_beans_MethodDescriptor;
};

// Vtype
struct _jc_java_beans_MethodDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_MethodDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_MethodDescriptor$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*m;
	_jc_object_array	*parameterDescriptors;
};

// Reference instance fields (object)
struct _jc_java_beans_MethodDescriptor$refs {
    _jc_java_beans_MethodDescriptor$sub_refs	java_beans_MethodDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_MethodDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_MethodDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_MethodDescriptor$sub_nonrefs	java_beans_MethodDescriptor;
};

// Object instance structure
struct _jc_java_beans_MethodDescriptor$object {
	_jc_java_beans_MethodDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_MethodDescriptor$vtype	*vtype;
	_jc_java_beans_MethodDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_MethodDescriptor$vtype _jc_java_beans_MethodDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_MethodDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_MethodDescriptor$class_object;

#endif	/* _JC_java_beans_MethodDescriptor_H_ */
